from _typeshed import Incomplete
from typing import Any
from rdkit import Chem as Chem
from rdkit.Chem import (
    rdMolDescriptors as rdMolDescriptors,
    rdPartialCharges as rdPartialCharges,
)
from rdkit.Chem.EState.EState import (
    MaxAbsEStateIndex as MaxAbsEStateIndex,
    MaxEStateIndex as MaxEStateIndex,
    MinAbsEStateIndex as MinAbsEStateIndex,
    MinEStateIndex as MinEStateIndex,
)
from rdkit.Chem.QED import qed as qed

def _isCallable(thing): ...

_descList: Incomplete

def _setupDescriptors(namespace) -> None: ...

MolWt: Incomplete

def HeavyAtomMolWt(x): ...

ExactMolWt: Incomplete

def NumValenceElectrons(mol): ...
def NumRadicalElectrons(mol): ...
def _ChargeDescriptors(mol, force: bool = ...): ...
def MaxPartialCharge(mol, force: bool = ...): ...
def MinPartialCharge(mol, force: bool = ...): ...
def MaxAbsPartialCharge(mol, force: bool = ...): ...
def MinAbsPartialCharge(mol, force: bool = ...): ...
def _FingerprintDensity(mol, func, *args, **kwargs): ...
def FpDensityMorgan1(x): ...
def FpDensityMorgan2(x): ...
def FpDensityMorgan3(x): ...

names: Incomplete
autocorr: Incomplete

def setupAUTOCorrDescriptors() -> None: ...

class PropertyFunctor(rdMolDescriptors.PythonPropertyFunctor):
    def __init__(self, name, version) -> None: ...
    def __call__(self, mol) -> Any: ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

PMI1: Incomplete
PMI2: Incomplete
PMI3: Incomplete
NPR1: Incomplete
NPR2: Incomplete
RadiusOfGyration: Incomplete
InertialShapeFactor: Incomplete
Eccentricity: Incomplete
Asphericity: Incomplete
SpherocityIndex: Incomplete



from rdkit import Chem
from rdkit.Chem import Mol, SDWriter
import io


def sample_mol() -> Mol:
    return Chem.MolFromSmiles("O=C(O)CCCCO/N=C(\\c1ccnnc1)c1cccc(C(F)(F)F)c1")


def frob(mol: Mol):
    for atom in mol.GetAtoms():
        a: Chem.Atom = atom
        _ = a
        n: int = atom.GetAtomicNum()
        assert type(n) == int


def sdwriter():
    t: str = SDWriter.GetText(sample_mol())
    assert type(t) == str

    bs = io.StringIO()
    writer = SDWriter(bs)
    for mol in [sample_mol(), sample_mol(), sample_mol()]:
        writer.write(mol)
    writer.close()
    first = bs.getvalue()

    bs = io.StringIO()
    with SDWriter(bs) as writer:
        for mol in [sample_mol(), sample_mol(), sample_mol()]:
            writer.write(mol)
    second = bs.getvalue()
    assert second == first

    writer = SDWriter(io.StringIO())
    writer.SetProps(["asdf"])
    writer.SetProps(("asdf",))


def test_frob():
    frob(sample_mol())
    sdwriter()



from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig
from rdkit.Chem import FragmentCatalog as FragmentCatalog
from rdkit.Dbase.DbConnection import DbConnect as DbConnect
from rdkit.ML import InfoTheory as InfoTheory

def message(msg, dest=...) -> None: ...
def BuildCatalog(
    suppl,
    maxPts: int = ...,
    groupFileName: Incomplete | None = ...,
    minPath: int = ...,
    maxPath: int = ...,
    reportFreq: int = ...,
): ...
def ScoreMolecules(
    suppl,
    catalog,
    maxPts: int = ...,
    actName: str = ...,
    acts: Incomplete | None = ...,
    nActs: int = ...,
    reportFreq: int = ...,
): ...
def ScoreFromLists(
    bitLists,
    suppl,
    catalog,
    maxPts: int = ...,
    actName: str = ...,
    acts: Incomplete | None = ...,
    nActs: int = ...,
    reportFreq: int = ...,
): ...
def CalcGains(
    suppl,
    catalog,
    topN: int = ...,
    actName: str = ...,
    acts: Incomplete | None = ...,
    nActs: int = ...,
    reportFreq: int = ...,
    biasList: Incomplete | None = ...,
    collectFps: int = ...,
): ...
def CalcGainsFromFps(
    suppl,
    fps,
    topN: int = ...,
    actName: str = ...,
    acts: Incomplete | None = ...,
    nActs: int = ...,
    reportFreq: int = ...,
    biasList: Incomplete | None = ...,
): ...
def OutputGainsData(outF, gains, cat, nActs: int = ...) -> None: ...
def ProcessGainsData(inF, delim: str = ..., idCol: int = ..., gainCol: int = ...): ...
def ShowDetails(
    catalog,
    gains,
    nToDo: int = ...,
    outF=...,
    idCol: int = ...,
    gainCol: int = ...,
    outDelim: str = ...,
) -> None: ...
def SupplierFromDetails(details): ...
def Usage() -> None: ...

class RunDetails:
    numMols: int
    doBuild: int
    doSigs: int
    doScore: int
    doGains: int
    doDetails: int
    catalogName: Incomplete
    onBitsName: Incomplete
    scoresName: Incomplete
    gainsName: Incomplete
    dbName: str
    tableName: Incomplete
    detailsName: Incomplete
    inFileName: Incomplete
    fpName: Incomplete
    minPath: int
    maxPath: int
    smiCol: int
    actCol: int
    nameCol: int
    hasTitle: int
    nActs: int
    nBits: int
    delim: str
    biasList: Incomplete
    topN: int

def ParseArgs(details) -> None: ...



from rdkit.Chem import *
from rdkit.Chem.ChemicalFeatures import *
from rdkit.Chem.rdChemReactions import (
    CartesianProductStrategy as CartesianProductStrategy,
    ChemicalReaction as ChemicalReaction,
    EnumerateLibrary as EnumerateLibrary,
    EnumerateLibraryBase as EnumerateLibraryBase,
    EnumerationParams as EnumerationParams,
    EnumerationStrategyBase as EnumerationStrategyBase,
    EvenSamplePairsStrategy as EvenSamplePairsStrategy,
    FingerprintType as FingerprintType,
    MOL_SPTR_VECT as MOL_SPTR_VECT,
    RandomSampleAllBBsStrategy as RandomSampleAllBBsStrategy,
    RandomSampleStrategy as RandomSampleStrategy,
    ReactionFingerprintParams as ReactionFingerprintParams,
    VectMolVect as VectMolVect,
    VectSizeT as VectSizeT,
    VectorOfStringVectors as VectorOfStringVectors,
    Compute2DCoordsForReaction as Compute2DCoordsForReaction,
    CreateDifferenceFingerprintForReaction as CreateDifferenceFingerprintForReaction,
    CreateStructuralFingerprintForReaction as CreateStructuralFingerprintForReaction,
    EnumerateLibraryCanSerialize as EnumerateLibraryCanSerialize,
    GetChemDrawRxnAdjustParams as GetChemDrawRxnAdjustParams,
    GetDefaultAdjustParams as GetDefaultAdjustParams,
    HasAgentTemplateSubstructMatch as HasAgentTemplateSubstructMatch,
    HasProductTemplateSubstructMatch as HasProductTemplateSubstructMatch,
    HasReactantTemplateSubstructMatch as HasReactantTemplateSubstructMatch,
    HasReactionAtomMapping as HasReactionAtomMapping,
    HasReactionSubstructMatch as HasReactionSubstructMatch,
    IsReactionTemplateMoleculeAgent as IsReactionTemplateMoleculeAgent,
    MatchOnlyAtRgroupsAdjustParams as MatchOnlyAtRgroupsAdjustParams,
    PreprocessReaction as PreprocessReaction,
    ReactionFromMolecule as ReactionFromMolecule,
    ReactionFromPNGFile as ReactionFromPNGFile,
    ReactionFromPNGString as ReactionFromPNGString,
    ReactionFromRxnBlock as ReactionFromRxnBlock,
    ReactionFromRxnFile as ReactionFromRxnFile,
    ReactionFromSmarts as ReactionFromSmarts,
    ReactionMetadataToPNGFile as ReactionMetadataToPNGFile,
    ReactionMetadataToPNGString as ReactionMetadataToPNGString,
    ReactionToMolecule as ReactionToMolecule,
    ReactionToRxnBlock as ReactionToRxnBlock,
    ReactionToSmarts as ReactionToSmarts,
    ReactionToSmiles as ReactionToSmiles,
    ReactionToV3KRxnBlock as ReactionToV3KRxnBlock,
    ReduceProductToSideChains as ReduceProductToSideChains,
    RemoveMappingNumbersFromReactions as RemoveMappingNumbersFromReactions,
    SanitizeRxn as SanitizeRxn,
    UpdateProductsStereochemistry as UpdateProductsStereochemistry,
)
from rdkit.Chem.rdDepictor import *
from rdkit.Chem.rdDistGeom import *
from rdkit.Chem.rdForceFieldHelpers import *
from rdkit.Chem.rdMolAlign import *
from rdkit.Chem.rdMolDescriptors import *
from rdkit.Chem.rdMolTransforms import *
from rdkit.Chem.rdPartialCharges import *
from rdkit.Chem.rdReducedGraphs import *
from rdkit.Chem.rdShapeHelpers import *
from rdkit.Chem.rdqueries import *
from rdkit.Chem.rdMolEnumerator import *
from rdkit.Chem.rdSLNParse import *
from _typeshed import Incomplete
from collections.abc import Generator
from rdkit import (
    DataStructs as DataStructs,
    ForceField as ForceField,
    RDConfig as RDConfig,
    rdBase as rdBase,
)
from rdkit.Chem.EnumerateStereoisomers import (
    EnumerateStereoisomers as EnumerateStereoisomers,
    StereoEnumerationOptions as StereoEnumerationOptions,
)
from rdkit.Geometry import rdGeometry as rdGeometry
from rdkit.RDLogger import logger as logger

def TransformMol(mol, tform, confId: int = ..., keepConfs: bool = ...) -> None: ...
def ComputeMolShape(
    mol, confId: int = ..., boxDim=..., spacing: float = ..., **kwargs
): ...
def ComputeMolVolume(
    mol, confId: int = ..., gridSpacing: float = ..., boxMargin: float = ...
): ...
def GetConformerRMS(
    mol, confId1, confId2, atomIds: Incomplete | None = ..., prealigned: bool = ...
): ...
def GetConformerRMSMatrix(
    mol, atomIds: Incomplete | None = ..., prealigned: bool = ...
): ...
def EnumerateLibraryFromReaction(
    reaction, sidechainSets, returnReactants: bool = ...
) -> Generator[Incomplete, None, None]: ...
def ConstrainedEmbed(
    mol,
    core,
    useTethers: bool = ...,
    coreConfId: int = ...,
    randomseed: int = ...,
    getForceField=...,
    **kwargs
): ...
def AssignBondOrdersFromTemplate(refmol, mol): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



import os
from collections.abc import Iterable
from pathlib import Path
from typing import List

from setuptools import setup


def walk_files(root_dir: Path) -> Iterable[Path]:
    for root, dirs, files in os.walk(root_dir):
        _ = dirs
        for filename in files:
            yield Path(root) / filename


def list_package_files() -> List[str]:
    root = Path("rdkit-stubs")
    return sorted(
        str(filepath.relative_to(root))
        for filepath in walk_files(root)
        if filepath.suffix == ".pyi"
    )


long_description = (Path(__file__).parent.resolve() / "README.md").read_text(
    encoding="utf-8"
)


setup(
    name="rdkit-stubs",
    version="0.1",
    description="type stubs for rdkit",
    author="Andrew Dirksen",
    author_email="andrew@dirksen.com",
    license="MIT OR Apache-2.0",
    url="https://github.com/postera-ai/rdkit-stubs",
    packages=["rdkit-stubs"],
    package_data={"rdkit-stubs": list_package_files()},
    classifiers=[
        "Development Status :: 1 - Planning",
        "Typing :: Stubs Only",
        "Programming Language :: Python :: 3.10",
    ],
    install_requires=["rdkit==2022.03.3"],
    long_description=long_description,
)



from _typeshed import Incomplete
from collections.abc import Generator
from rdkit import Chem as Chem

environs: Incomplete
reactionDefs: Incomplete
smartsGps: Incomplete
g1: Incomplete
g2: Incomplete
bnd: Incomplete
r1: Incomplete
r2: Incomplete
sma: Incomplete
t: Incomplete
environMatchers: Incomplete
bondMatchers: Incomplete
tmp: Incomplete
e1: Incomplete
e2: Incomplete
patt: Incomplete
reactions: Incomplete
reverseReactions: Incomplete
rs: Incomplete
ps: Incomplete
rxn: Incomplete
labels: Incomplete

def FindBRICSBonds(
    mol, randomizeOrder: bool = ..., silent: bool = ...
) -> Generator[Incomplete, None, None]: ...
def BreakBRICSBonds(
    mol, bonds: Incomplete | None = ..., sanitize: bool = ..., silent: bool = ...
): ...
def BRICSDecompose(
    mol,
    allNodes: Incomplete | None = ...,
    minFragmentSize: int = ...,
    onlyUseReactions: Incomplete | None = ...,
    silent: bool = ...,
    keepNonLeafNodes: bool = ...,
    singlePass: bool = ...,
    returnMols: bool = ...,
): ...

dummyPattern: Incomplete

def BRICSBuild(
    fragments,
    onlyCompleteMols: bool = ...,
    seeds: Incomplete | None = ...,
    uniquify: bool = ...,
    scrambleReagents: bool = ...,
    maxDepth: int = ...,
) -> Generator[Incomplete, None, None]: ...
def _test(): ...
